@@ -4,17 +4,17 @@
     <message>
         <location filename="../calendarwindow.cpp" line="203"/>
         <source>First Day of Week</source>
-        <translation type="unfinished"/>
+        <translation>Долоо хоногийн эхний өдөр</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="40"/>
         <source>Deepin Calendar</source>
-        <translation type="unfinished"/>
+        <translation>Деепин Хуанли</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="42"/>
         <source>Calendar is a date tool.</source>
-        <translation type="unfinished"/>
+        <translation>Хуанли нь огноо, цагалбарын хэрэгсэл.</translation>
     </message>
 </context>
 <context>
